/* ----------------------------------------------------------------------------
 * Raima Database Manager
 *
 * Copyright (c) 2014 Raima Inc.,  All rights reserved.
 *
 * Use of this software, whether in source code format, or in executable,
 * binary object code form, is governed by the Raima LICENSE which
 * is fully described in the LICENSE.TXT file, included within this
 * distribution of files.
 * ----------------------------------------------------------------------------
 */

/** \file rdmencryptapi.h
 *  \brief Header for the RDM Encryption APIs
 */

#include "rdmtypes.h"

/**
 *
 * \defgroup encrypt RDM Encryption API
 *
 * The encryption library.  The functions here are located in \lib{enc}
 * See the \ref rdm_encryption for how to instantiate an encryption context.
 *
 * \ingroup rdm
 * \addtogroup encrypt
 * @{*/

#if defined(__cplusplus)
extern "C" {
#endif

/** \brief Free an encryption context

    This function will cleanup and free an encryption context. Once the
    encryption context and been freed it will not be used when open a database.

    \par Locking Requirements
    None

    \see rdm_tfsAllocEncrypt

    \retval sOKAY Success
 */
RDM_EXPORT RDM_RETCODE EXTERNAL_FCN rdm_encryptFree (
    RDM_ENCRYPT enc /**< Pointer to an encryption context */
);

/** \brief Get the encryption type for an allocated encryption context

    This function will return the encryption type for an allocated encryption
    context.

    \par Locking Requirements
    None

    \see rdm_encryptFree

    \retval sOKAY Success
 */
RDM_EXPORT RDM_RETCODE EXTERNAL_FCN rdm_encryptGetType (
    RDM_ENCRYPT enc,    /**< [IN] An encryption context */
    RDM_ENC_TYPE *ptype /**< [OUT] A pointer to a RDM_ENC_TYPE */
);

#if defined(__cplusplus)
}
#endif

/** @}*/
