/*
 * Raima Database Manager
 *
 * Copyright (C) 2016 Raims Inc.,  All rights reserved.
 *
 * Use of this software, whether in source code format, or in executable,
 * binary object code form, is governed by the Raima LICENSE which
 * is fully described in the LICENSE.TXT file, included within this
 * distribution of files.
 */

/** \file rdmuuidtypes.h
 *  \brief Header for Universally Unique Identifier (UUID) types
 */

#if !defined(RDMUUIDTYPES_H_INCLUDED_)
#define RDMUUIDTYPES_H_INCLUDED_

#include "psptypes.h"

/** \brief The RDM UUID data structure
 */
typedef struct
{
    uint32_t time_low; /**< The 32 least significant bits of the time */
    uint16_t time_mid; /**< The 16 middle significant bits of the time */
    uint16_t time_high_and_version; /**< The 4 most significant bits of the version
                                       followed by the 12 most significant bits of the time */
    uint8_t clock_seq_high_and_reserved; /**< The most significant part of the
                                            clock sequence and reserved bits */
    uint8_t clock_seq_low; /**< The least significant part of the clock sequence */
    uint8_t node[6];       /**< The 48 bit node ID */
} RDM_UUID_T;

#define RDM_UUID_STRLEN                                                        \
    37 /**< The maximum string length of an UUID including the NULL terminator but not the braces */
#define LITERAL_NULL_UUID                                                      \
    {                                                                          \
        0, 0, 0, 0, 0,                                                         \
        {                                                                      \
            0, 0, 0, 0, 0, 0                                                   \
        }                                                                      \
    } /**< The null UUID */

#endif /* RDMUUIDTYPES_H_INCLUDED_ */
